@@ -32,7 +32,7 @@ class Stepfunctions(core.Construct):
         )
 
     def _invoke_lambda(self, name: str, fx: aws_lambda.IFunction=None,
-        code: aws_lambda.Code=None, handler: str=None, runtime=aws_lambda.Runtime.PYTHON_3_7,
+        code: aws_lambda.AssetCode=None, handler: str=None, runtime=aws_lambda.Runtime.PYTHON_3_7,
         **invoke_attr) -> sfn_tasks.LambdaInvoke:
         if not fx:
             fx = aws_lambda.Function(
